@@ -1,7 +1,6 @@
 # ------------------------------------------------------------------------------
-# Name: rindcalc.cloud_masking.py
+# Name: rindcalc.ls.cloud_masking.py
 # Author: Owen Smith, University of North Georgia IESA
-# Purpose: Cloud mask function for rindcalc. Will be combined with band_utils
 # ------------------------------------------------------------------------------
 
 import os
@@ -12,10 +11,8 @@ from glob import glob
 
 def cloud_mask_array(landsat_dir, array):
     """
-
-    :param landsat_dir:
-    :param band:
-    :return:
+    This function masks clouds in Landsat-8 imagery using the QA band and
+    returns an array to save as a raster.
     """
     qa = glob(os.path.join(landsat_dir, '*BQA*'))
     gdal.UseExceptions()
